
Authors
=======
Steven Murray: `@steven-murray <https://github.com/steven-murray>`_

Contributors
------------
* Francis Poulin `@francispoulin <https://github.com/francispoulin>`_
* Sebastian Mueller `@MuellerSeb <https://github.com/MuellerSeb>`_
